from .structures import EventCall, EventHandler, EventSupport, Contains
from .exceptions import UncancellableEvent
from .event_space import EventSpace, global_event_space

__name__ = "pyding"
__version__ = "1.8.3"

def __getattr__(attr):
    return global_event_space.__getattribute__(attr)

def __dir__():
    return global_event_space.__dir__()


import setuptools
import pyding

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="pyding",
    version=pyding.__version__,
    author = 'João Lucas Bernardi',
    author_email="joao_bernardi@outlook.com",
    description="Simpĺe but effective event framework",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url = 'https://github.com/jaobernardi/pyding',
    packages=setuptools.find_packages(),
    classifiers=[
        'Development Status :: 5 - Production/Stable',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        'Intended Audience :: Developers',      # Define that your audience are developers
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',   # Again, pick a license
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
    ],
    include_package_data=True,
    python_requires=">=3.6",
)